@@ -54,3 +54,7 @@ $ #WorkspaceWarping
 # Workspace Warping
 $ #DesktopWheeling
 # Desktop Wheeling
+$ #AntiAlias
+# AntiAlias
+$ #DecorateTransient
+# Decorate Transient
