@@ -7,10 +7,12 @@ $ #DISPLAYRequiresArg
 $ #WarnDisplaySet
 # :        'DISPLAY'\n
 $ #Usage
-# Fluxkbox %s: (c) 2001 Henrik Kinnunen\n\n\
+# Fluxkbox %s: (c) %s Henrik Kinnunen\n\n\
   -display <string>\t\tuse display connection.\n\
   -rc <string>\t\t\t   .\n\
   -version\t\t\t   .\n\
+  -info\t\t\t\tdisplay some useful information.\n\
+  -log <filename>\t\t\tlog output to file.\n\
   -help\t\t\t\t     .\n\n
 $ #CompileOptions
 #      :\n\
