@@ -54,3 +54,5 @@ $ #WorkspaceWarping
 # ɥɥåǥڡư
 $ #DesktopWheeling
 # ޥۥǥڡڤ괹
+$ #AntiAlias
+# ꥢ
