@@ -7,10 +7,12 @@ $ #DISPLAYRequiresArg
 $ #WarnDisplaySet
 # warning: Ķѿ 'DISPLAY' ǤޤǤ\n
 $ #Usage
-# Fluxbox %s: (c) 2001 Henrik Kinnunen\n\n\
+# Fluxbox %s: (c) %s Henrik Kinnunen\n\n\
   -display <string>\t\t ǥץ쥤³.\n\
   -rc <string>\t\t\t Υ꥽ե.\n\
   -version\t\t\t Сɽƽλ.\n\
+  -info\t\t\t\tdisplay some useful information.\n\
+  -log <filename>\t\t\tlog output to file.\n\
   -help\t\t\t\t Υإפɽƽλ.\n\n
 $ #CompileOptions
 # ѥΥץ:\n\
