@@ -51,6 +51,9 @@ $ #MaxOverSlit
 $ #SloppyWindowGrouping
 # Hafsig Fnster Gruppering
 $ #WorkspaceWarping
-# Workspace Warping
+# Dra fnster mellan arbetsytor
 $ #DesktopWheeling
-# Desktop Wheeling
+# ndra arbetsyta med mushjulet
+$ #AntiAlias
+# Kantutjmning
+
