@@ -7,10 +7,12 @@ $ #DISPLAYRequiresArg
 $ #WarnDisplaySet
 # varning: kunde inte stta variabeln 'DISPLAY'\n
 $ #Usage
-# Fluxbox %s: (c) 2001-2002 Henrik Kinnunen\n\n\
-  -display <string>\t\tanvnd skrmanslutning.\n\
-  -rc <string>\t\t\tanvnd alternativ resursfil.\n\
+# Fluxbox %s: (c) %s Henrik Kinnunen\n\n\
+  -display <strng>\t\tanvnd skrmanslutning.\n\
+  -rc <strng>\t\t\tanvnd alternativ resursfil.\n\
   -version\t\t\tvisa version och avsluta.\n\
+  -info\t\t\t\tVisar nyttig information.\n\
+  -log <filenamn>\t\t\tloggar utskriften till en fil.\n\
   -help\t\t\t\tvisa denna hjlptext och avsluta.\n\n
 $ #CompileOptions
 # Kompilerad med:\n\
