@@ -3,31 +3,31 @@ $set 3 #Configmenu
 $ #ConfigOptions
 # Ayarlar
 $ #FocusModel
-# Foksleme
+# Hizalama
 $ #WindowPlacement
 # Pencere yerleimi
 $ #ImageDithering
-# Resim oluturmas
+# Resim oluturulmas
 $ #OpaqueMove
-# Ekran ierikli ta
+# Donuk Pencere Tanmas
 $ #FullMax
-# Tam ekranla, vallahi
+# Ekran Kapla
 $ #FocusNew
-# Yeni pencereleri foksle
+# Yeni Pencereleri Hizala
 $ #FocusLast
-# Masastndeki son pencereyi foksle
+# Masast deiiminde pencereyi hizala
 $ #ClickToFocus
-# Tklayarak foksle
+# Hizalamak iin tkla
 $ #SloppyFocus
-# Ar foksle
+# Yava Hizala
 $ #AutoRaise
-# Otomatikman ykselt
+# Otomatik Gster
 $ #SmartRows
-# Akll yerleim( Sralar )
+# Akll Yerleim( Sralar )
 $ #SmartCols
-# Akll yerleim( Stunlar )
+# Akll Yerleim( Stunlar )
 $ #Cascade
-# Cascade Placement
+# Kademeli Yerleim
 $ #LeftRight
 # Soldan saa
 $ #RightLeft
@@ -37,20 +37,20 @@ $ #TopBottom
 $ #BottomTop
 # Alttan ste
 $ #Tabs
-# Use Tabs
+# Sekmeleri Kullan
 $ #Icons
-# Use Icons
+# Sekme konlar
 $ #TabPlacement
-# Tab Placement
+# Sekme Yerleimi
 $ #TabRotateVertical
-# Rotate Vertical Tabs
+# Sekmeleri Dey Yerletir
 $ #SemiSloppyFocus
-# Semi Sloppy Focus
+# Aynlar Hizala
 $ #MaxOverSlit
-# Maximize Over Slit
+# Kesik zerinden Ekran Kapla
 $ #SloppyWindowGrouping
-# Sloppy Window Grouping
+# Penecere Gruplandrmas
 $ #WorkspaceWarping
-# Workspace Warping
+# Masast Sapmas
 $ #DesktopWheeling
-# Desktop Wheeling
+# Masast Geii
