@@ -2,16 +2,16 @@ $set 9 #Window
 
 
 $ #Creating
-# BlackboxWindow::BlackboxWindow : 0x%lx'i yarat#_yorum\n
+# BlackboxWindow::BlackboxWindow : 0x%lx oluturuluyor\n
 $ #XGetWindowAttributesFail
 # BlackboxWindow::BlackboxWindow : XGetWindowAttributres baarsz oldu\n
 $ #CannotFindScreen
 # BlackboxWindow::BlackboxWindow : 0x%lx ana penceresi iin ekran belirleyemedim\n
 $ #Unnamed
-# Isimsiz
+# simsiz
 $ #MapRequest
 # 0x%lx iin BlackboxWindow::mapRequestEvent()\n
 $ #UnmapNotify
 # 0x%lx iin BlackboxWindow::unmapNotifyEvent()\n
 $ #UnmapNotifyReparent
-# BlackboxWindow::unmapnotifyEvent: 0x%lx'i ana pencereyi boya\n
+# BlackboxWindow::unmapnotifyEvent: 0x%lx ana ekrana gnder\n
