@@ -8,7 +8,7 @@ $ #No
 $ #DirectionTitle
 # Yn
 $ #DirectionHoriz
-# Ufki
+# Yatay
 $ #DirectionVert
 # Dikey
 
@@ -34,25 +34,25 @@ $ #PlacementCenterRight
 $ #PlacementBottomRight
 # Sa st
 $ #PlacementLeftTop
-# Left Top
+# Sol st
 $ #PlacementLeftCenter
-# Left Center
+# Sol orta
 $ #PlacementLeftBottom
-# Left Bottom
+# Orta sol
 $ #PlacementRightTop
-# Right Top
+# Sa st
 $ #PlacementRightCenter
-# Right Center
+# Orta sa
 $ #PlacementRightBottom
-# Right Bottom
+# Sa orta
 $ #PlacementTopRelative
-# Top Relative
+# st
 $ #PlacementBottomRelative
-# Bottom Relative
+# Orta
 $ #PlacementLeftRelative
-# Left Relative
+# Sol
 $ #PlacementRightRelative
-# Right Relative
+# Sa
 
 $ #AutoHide
-# Auto hide
+# Otomatik Gizle
